#
# spec file for package python-monascaclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-monascaclient
Name:           python-monascaclient
Version:        1.5.0
Release:        2.2
Summary:        Python API and CLI for OpenStack Monasca
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
# from https://review.openstack.org/#/c/457663/
Patch1:         0001-Added-support-for-os_auth_version-when-os_auth_url-i.patch
BuildRequires:  openstack-macros
BuildRequires:  python-PrettyTable >= 0.7.1
BuildRequires:  python-PyYAML >= 3.10.0
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-keystoneclient >= 3.8.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-mox3 >= 0.7.0
BuildRequires:  python-oslo.concurrency >= 3.8.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.log >= 3.11.0
BuildRequires:  python-oslo.serialization >= 1.10.0
BuildRequires:  python-oslo.utils >= 3.18.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-requests-mock >= 1.1
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-Babel >= 2.3.4
Requires:       python-PrettyTable >= 0.7.1
Requires:       python-PyYAML >= 3.10.0
Requires:       python-keystoneclient >= 3.8.0
Requires:       python-oslo.concurrency >= 3.8.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.log >= 3.11.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.service >= 1.10.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-pbr >= 1.8
Requires:       python-requests >= 2.10.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
This is a client library for Monasca built to interface with the Monasca API. It
provides a Python API (the ``monascaclient`` module) and a command-line tool
(``monasca``).

The Monasca Client was written using the OpenStack Heat Python client as a framework.

%prep
%autosetup -p1 -n %{sname}-%{version}
%py_req_cleanup

%build
%py2_build

%install
%py2_install
# bash completion
install -p -D -m 644 tools/monasca.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/monasca.bash_completion
rm -f %{buildroot}%{_datarootdir}/monasca.bash_completion

%check
%{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{python2_sitelib}/monascaclient
%{python2_sitelib}/*.egg-info
%{_sysconfdir}/bash_completion.d/monasca.bash_completion
%{_bindir}/monasca

%changelog
* Tue Apr 18 2017 tbechtold@suse.com
- Add 0001-Added-support-for-os_auth_version-when-os_auth_url-i.patch
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.5.0:
  - Add CONTRIBUTING.rst
  - Updated from global requirements
  - Show team and repo badges on README
  - Don't send X-Auth- headers in requests
  - H803 hacking have been deprecated
  - Use requests-mock instead of custom fakes
  - Use the new copy of tox_install.sh for global constraints support
  - Remove support for py33
  - Typo fix: recieve => receive
  - Add __ne__ built-in function
  - Use correct ENV variables for scoping
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.4.0:
  - Remove a space of Docstring
  - Fix dimension validation and help message for alarm count
  - Patch-notification failed with period=0
  - Fix LOG.warn to LOG.warning
  - move old apiclient code out of openstack/common
  - Dimension value list doesn't recognize dimension name input
  - Change LOG.warn to LOG.warning
  - Add notification-patch into CLI
  - Add support for new rest api notification-type-list
  - Fix monasca enpoint port in example and README
  - Remove discover from test-requirements
  - Add list_next for pagination
  - Add list dimension names and values in CLI
  - Changed author and author-email
  - Prevent potentially destructive updates on data
  - Add py35 tox environment
  - Add state-updated-timestamp filter to alarm count CLI
  - use six.moves.urllib.parse instead of py3kcompat
  - remove unused openstack/common/gettextutils.py
  - Use constraints everywhere
  - Fixes H904: wrapping using parantheses
  - Correct reraising of exception
  - Fix __str__ not returning a String for KeystoneException
  - Sync tools/tox_install.sh
  - Remove white space between print and ()
  - Fix monasca notification-show help message
  - Sample nagios plugin and examples directory.
  - Updated from global requirements
  - Delete deprecated Hacking in tox.ini
* Wed Dec  7 2016 dmueller@suse.com
- Initial package (1.2.0)
